@@ -218,6 +218,11 @@ def misiak_correlation(x: np.ndarray, y: np.ndarray, X: np.ndarray) -> np.float6
             1-D data vector
         X: array_like
             m x n data matrix
+
+    Returns
+    ----------
+        : float
+            Misak correlation score.
     '''
     G = np.empty((X.shape[1]+1, X.shape[1]+1))
     G[0, 0] = x @ y
@@ -249,6 +254,7 @@ def multisemideviation(X: np.ndarray, p=1) -> np.float64:
     ----------
         X: array_like
             m x n data matrix
+
     Returns
     ----------
         : float
@@ -266,6 +272,25 @@ def multisemideviation(X: np.ndarray, p=1) -> np.float64:
     result = np.power(result, 1/p)
     return result
 
+def signum_correlation(X: np.ndarray) -> np.float64:
+    '''
+    Signum correlation coefficient.
+
+    Parameters
+    ----------
+        X: array_like
+            m x n data matrix
+
+    Returns
+    ----------
+        : float
+            Signum correlation score.
+    '''
+    transform = X - np.mean(X, axis=0)
+    transform = np.sign(transform)
+    return reflective_correlation(transform)
+
+
 def taylor_correlation(X: np.ndarray) -> np.float64:
     '''
     Taylor's multi-way correlation coefficient.
@@ -280,7 +305,7 @@ def taylor_correlation(X: np.ndarray) -> np.float64:
 
     .. math::
 
-        \frac{1}{\sqrt{d}} \sqrt{\frac{1}{d-1} \sum_{i}^{d} ( \lambda_i \bar{\lambda})^2 }
+        \\frac{1}{\\sqrt{d}} \\sqrt{\\frac{1}{d-1} \\sum_{i}^{d} ( \\lambda_i \\bar{\\lambda})^2 }
 
     where :math:`d` is the number of variables, :math:`\lambda_1, \cdots, \lambda_d` are the eigenvalues of
     the correlation matrix for a given set of variables, and :math:`\bar{\lambda}` is the mean of those eigenvalue.
@@ -311,6 +336,10 @@ def trencevski_melceski_correlation(X: np.ndarray, Y: np.ndarray) -> np.float64:
     ----------
         : float
             Correlation score.
+
+    References
+    ----------
+    .. [1] Trencevski, Kostadin. Malceski, Risto. 2006. "On a generalized n-inner product and the corresponding Cauchy-Schwarz inequality", https://www.researchgate.net/publication/268999118_On_a_generalized_n-inner_product_and_the_corresponding_Cauchy-Schwarz_inequality
     '''
     numerator = np.linalg.det(X.T @ Y)
     denominator = np.linalg.det(X.T @ X) *\
